@@ -1,13 +1,13 @@
 package Acme::Playpen;
 
-our $VERSION = '0.16';
-
 use strict;
 use warnings;
 use 5.006;
 
 use Acme::Playpen::Utilities;
 
+package Acme::odometer;
+
 1;
 
 =head1 NAME
